@@ -4,7 +4,7 @@ import enum
 
 class Constant(enum.Enum):
     """ constant """
-    root_url = "https://develop.scoredata.com"
+    root_url = "https://console.scoredata.com"
     dataset_url = "{}/api/imported_data/".format(root_url)
     dataset_download_url = "{}/api/dataset/download/".format(root_url)
     model_download_url = "{}/api/model/download".format(root_url)
